function DBFs = createDBF( DPDD, DTra, BasisDir, lecDir, b)
%createDBF      Compute the DBFs matrix for the DBF model.
%
%   DBFs = createDBF( DPDD, DTra, BasisDir, lecDir , nTensoresBase, NLEC, b)
%   Compute the the DBFS matrix given the basis-tensor's longitudinal and transversal 
%   diffusion DPDD and DTRA for the set of orientations BASISDIR and for the set of
%   diffusion encoding orientation (MRI machine gradient directions) LECDIR and b-value
%   B, as is explained in:
%   A. Ramirez-Manzanares etal, Diffusion Basis Functions Decomposition for Estimating 
%   White Matter Intravoxel Fiber Geometry. IEEE Trans. Med. Imaging 26(8): 2007.
%
%   Alonso Ramirez.  
%   $Date: 2008/10/21$

nTensoresBase = size(BasisDir,1);
NLEC = size(lecDir,1);

DBFs = zeros(NLEC,nTensoresBase);

T = [DPDD 0 0 ; 0 DTra 0; 0 0 DTra]; % A base tensor along X-axis

for j=1:nTensoresBase
    mtx = fromToRotation([1 ;0 ;0], BasisDir(j,:)'); %compute rotation matrix
    Ti = mtx * T * mtx';
    %compute the DW-signals for each tensor
    for i=1:NLEC
         DBFs(i,j) = exp(-b * lecDir(i,:) * Ti * lecDir(i,:)');
    end
end

