function [sizeCluster,idxsCluster,processed,nProcessed] = findCluster(alfas,processed,basisDNeigh,nProcessed,nv,threshold)
%findCluster      Find a cluster of orientations to fusion.
%
%   [sizeCluster,idxsCluster,processed,nProcessed] = findCluster(alfas,processed,basisDNeigh,nProcessed,nv,threshold) 
%   Given a vector of NV discrete orientation alpha coefficients ALFAS, whith orientation neighborhood BASISDNEIGH, 
%   the function computes a  cluster of orientation to collapse by taking into account the distance between them and 
%   if they aron processed yet (marked in PROCESSED). THRESHOLD indicates the minimum value of an ALFAS coefficient 
%   to be taken into account. The function returns the number of orientations fusioned SIZECLUSTER, the index of the used 
%   discrete orientations IDXSCLUSTER and the index of the NPROCESSED already processed index in PROCESSED.
%
%   Alonso Ramirez.  
%   $Date: 2008/10/21$

sizeCluster = 0;

idxsCluster = zeros(20,1);


[salfas, sidx] = sort(alfas);


while 1
    
    change = 0;
    for i=nv:-1:1
        if alfas(sidx(i)) > threshold
            
            if max(processed == sidx(i) )==0 & max(idxsCluster == sidx(i))==0 % if no processed and not in the current cluster
                if sizeCluster == 0 % is the first point?
                    sizeCluster = sizeCluster + 1;
                    idxsCluster(sizeCluster) = sidx(i);
                    change = change + 1;
                    nProcessed = nProcessed + 1; processed(nProcessed) = sidx(i);
                else %there are previous points
                    for j=1:sizeCluster % look if this point is in the neighborhood of any in the cluster
                        if max(basisDNeigh(idxsCluster(j),:) == sidx(i))~= 0 % sidx(i) is in the neighborhood of j ?
                            sizeCluster = sizeCluster + 1;
                            idxsCluster(sizeCluster) = sidx(i);
                            change = change + 1;
                            nProcessed = nProcessed + 1; processed(nProcessed) = sidx(i);
                            if sizeCluster == 5
                                return;
                            end
                            break;
                        end
                    end
                end
            end            
        end
    end
    if change ==0 %if no new points were added
        break;
    end
end
