function [nCentroids,centroids,amountDiffs,sizeClusters] = giveContinousPDDS(alphas,BasisDir,basisDNeigh,threshold,nMaxDifs)
%giveContinousPDDS      Compute continuos solution given DBF discrete solution.
%
%   [nCentroids,centroids,amountDiffs,sizeClusters] = giveContinousPDDS(alphas,BasisDir,basisDNeigh,threshold,nMaxDifs) 
%   Given te discrete DBF discrete solution ALPHAS, BASISDIRS, as explained in:
%   A. Ramirez-Manzanares etal, Diffusion Basis Functions Decomposition for Estimating 
%   White Matter Intravoxel Fiber Geometry. IEEE Trans. Med. Imaging 26(8): 2007.,
%   The function computes the continuos solution reporting the number #NCENTROIDS of multi-directions computed, 
%   the directions of diffusion in CENTROIDS, the amount of each one in AMOUNTDIFF, and the number of discrete orientations
%   that were fusioned in SIZECLUSTER.
%
%   Alonso Ramirez.  
%   $Date: 2008/10/21$

[nv,nc] = size(alphas);


processed = zeros(size(alphas));
nProcessed = 0;
nCentroids = 0;
centroids = zeros(nMaxDifs,3);
amountDiffs = zeros(nMaxDifs,1);
sizeClusters = zeros(nMaxDifs,1);
while 1
    [sizeCluster,idxsCluster,processed,nProcessed] = findCluster(alphas,processed,basisDNeigh,nProcessed,nv,threshold);
    if sizeCluster == 0
        break;
    end
    [centroid,amountDiff] = continuosCollapsing(sizeCluster,idxsCluster,BasisDir,alphas);    
    nCentroids = nCentroids + 1;
    centroids(nCentroids,:) = centroid;
    amountDiffs(nCentroids) = amountDiff;
    sizeClusters(nCentroids) = sizeCluster;
    if nCentroids == nMaxDifs
        break
    end
        
end

