function [nCoef,CoeffDeff,nxsyszs,mu,matHRT,fac_m_i_b_mu,T] = preComputeHRTenData(rank,NLEC,orientations,b)
%preComputeHRTenData      Compute preliminar data for high rank tensor fitting.
%
%   [nCoef,CoeffDeff,nxsyszs,mu,matHRT,fac_m_i_b_mu,T] = preComputeHRTenData(rank,NLEC,orientations,b)
%                       Compute tables of coeffcients for fitting a high RANK tensor for a signal of size 
%                       NLEC aquired in orientation ORIENTATIONS  with b value B as explained in
%                       'Özarslan E. etal, (2003) Generalized diffusion tensor imaging 
%                       and analytical relationships between diffusion tensor imaging 
%                       and high angular resolution diffusion imaging. Magn. Reson. Med.'
%                       Computed values are used in computeHighRankTensor function.
%                       
%
%   Alonso Ramirez.  
%   $Date: 2008/10/21$


x=1; y=2; z=3;

%Tables according Ozarslan and Mareci paper
%                       'Özarslan E. etal, (2003) Generalized diffusion tensor imaging 
%                       and analytical relationships between diffusion tensor imaging 
%                       and high angular resolution diffusion imaging. Magn. Reson. Med.'

if rank == 2
    nCoef = 6;
    CoeffDeff = zeros(nCoef,rank);
    nxsyszs = zeros(nCoef,3);
    mu = zeros(nCoef,1);
    CoeffDeff( 1,:) = [x x]; nxsyszs( 1,:) = [2 0 0]; mu( 1) = 1;
    CoeffDeff( 2,:) = [y y]; nxsyszs( 2,:) = [0 2 0]; mu( 2) = 1;
    CoeffDeff( 3,:) = [z z]; nxsyszs( 3,:) = [0 0 2]; mu( 3) = 1;
    CoeffDeff( 4,:) = [x y]; nxsyszs( 4,:) = [1 1 0]; mu( 4) = 2;
    CoeffDeff( 5,:) = [x z]; nxsyszs( 5,:) = [1 0 1]; mu( 5) = 2;
    CoeffDeff( 6,:) = [y z]; nxsyszs( 6,:) = [0 1 1]; mu( 6) = 2;

    T = [ ...
        4 0 0 5; ...
        2 2 0 15 ];
    
elseif rank==4
    nCoef = 15;
    CoeffDeff = zeros(nCoef,rank);
    nxsyszs = zeros(nCoef,3);
    mu = zeros(nCoef,1);
    CoeffDeff( 1,:) = [x x x x]; nxsyszs( 1,:) = [4 0 0]; mu( 1) = 1;
    CoeffDeff( 2,:) = [y y y y]; nxsyszs( 2,:) = [0 4 0]; mu( 2) = 1;
    CoeffDeff( 3,:) = [z z z z]; nxsyszs( 3,:) = [0 0 4]; mu( 3) = 1;
    CoeffDeff( 4,:) = [x x x y]; nxsyszs( 4,:) = [3 1 0]; mu( 4) = 4;
    CoeffDeff( 5,:) = [x x x z]; nxsyszs( 5,:) = [3 0 1]; mu( 5) = 4;
    CoeffDeff( 6,:) = [y y y x]; nxsyszs( 6,:) = [1 3 0]; mu( 6) = 4;
    CoeffDeff( 7,:) = [y y y z]; nxsyszs( 7,:) = [0 3 1]; mu( 7) = 4;
    CoeffDeff( 8,:) = [z z z x]; nxsyszs( 8,:) = [1 0 3]; mu( 8) = 4;
    CoeffDeff( 9,:) = [z z z y]; nxsyszs( 9,:) = [0 1 3]; mu( 9) = 4;
    CoeffDeff(10,:) = [x x y y]; nxsyszs(10,:) = [2 2 0]; mu(10) = 6;
    CoeffDeff(11,:) = [x x z z]; nxsyszs(11,:) = [2 0 2]; mu(11) = 6;
    CoeffDeff(12,:) = [y y z z]; nxsyszs(12,:) = [0 2 2]; mu(12) = 6;
    CoeffDeff(13,:) = [x x y z]; nxsyszs(13,:) = [2 1 1]; mu(13) =12;
    CoeffDeff(14,:) = [y y x z]; nxsyszs(14,:) = [1 2 1]; mu(14) =12;
    CoeffDeff(15,:) = [z z x y]; nxsyszs(15,:) = [1 1 2]; mu(15) =12;

    T = [ ...
        8 0 0 9; ...
        6 2 0 63; ...
        4 4 0 105; ...
        4 2 2 315];
    
    
elseif rank==6
    nCoef = 28;
    CoeffDeff = zeros(nCoef,rank);
    nxsyszs = zeros(nCoef,3);
    mu = zeros(nCoef,1);
    CoeffDeff( 1,:) = [x x x x x x]; nxsyszs( 1,:) = [6 0 0]; mu( 1) = 1;
    CoeffDeff( 2,:) = [y y y y y y]; nxsyszs( 2,:) = [0 6 0]; mu( 2) = 1;
    CoeffDeff( 3,:) = [z z z z z z]; nxsyszs( 3,:) = [0 0 6]; mu( 3) = 1;
    CoeffDeff( 4,:) = [x x x x x y]; nxsyszs( 4,:) = [5 1 0]; mu( 4) = 6;
    CoeffDeff( 5,:) = [x x x x x z]; nxsyszs( 5,:) = [5 0 1]; mu( 5) = 6;
    CoeffDeff( 6,:) = [y y y y y x]; nxsyszs( 6,:) = [1 5 0]; mu( 6) = 6;
    CoeffDeff( 7,:) = [y y y y y z]; nxsyszs( 7,:) = [0 5 1]; mu( 7) = 6;
    CoeffDeff( 8,:) = [z z z z z x]; nxsyszs( 8,:) = [1 0 5]; mu( 8) = 6;
    CoeffDeff( 9,:) = [z z z z z y]; nxsyszs( 9,:) = [0 1 5]; mu( 9) = 6;
    CoeffDeff(10,:) = [x x x x y y]; nxsyszs(10,:) = [4 2 0]; mu(10) =15;
    CoeffDeff(11,:) = [x x x x z z]; nxsyszs(11,:) = [4 0 2]; mu(11) =15;
    CoeffDeff(12,:) = [y y y y x x]; nxsyszs(12,:) = [2 4 0]; mu(12) =15;
    CoeffDeff(13,:) = [y y y y z z]; nxsyszs(13,:) = [0 4 2]; mu(13) =15;
    CoeffDeff(14,:) = [z z z z x x]; nxsyszs(14,:) = [2 0 4]; mu(14) =15;
    CoeffDeff(15,:) = [z z z z y y]; nxsyszs(15,:) = [0 2 4]; mu(15) =15;
    CoeffDeff(16,:) = [x x x y y y]; nxsyszs(16,:) = [3 3 0]; mu(16) =20;
    CoeffDeff(17,:) = [x x x z z z]; nxsyszs(17,:) = [3 0 3]; mu(17) =20;
    CoeffDeff(18,:) = [y y y z z z]; nxsyszs(18,:) = [0 3 3]; mu(18) =20;
    CoeffDeff(19,:) = [x x x x y z]; nxsyszs(19,:) = [4 1 1]; mu(19) =30;
    CoeffDeff(20,:) = [y y y y x z]; nxsyszs(20,:) = [1 4 1]; mu(20) =30;
    CoeffDeff(21,:) = [z z z z x y]; nxsyszs(21,:) = [1 1 4]; mu(21) =30;
    CoeffDeff(22,:) = [x x x y y z]; nxsyszs(22,:) = [3 2 1]; mu(22) =60;
    CoeffDeff(23,:) = [x x x z z y]; nxsyszs(23,:) = [3 1 2]; mu(23) =60;
    CoeffDeff(24,:) = [y y y x x z]; nxsyszs(24,:) = [2 3 1]; mu(24) =60;
    CoeffDeff(25,:) = [y y y z z x]; nxsyszs(25,:) = [1 3 2]; mu(25) =60;
    CoeffDeff(26,:) = [z z z x x y]; nxsyszs(26,:) = [2 1 3]; mu(26) =60;
    CoeffDeff(27,:) = [z z z y y x]; nxsyszs(27,:) = [1 2 3]; mu(27) =60;
    CoeffDeff(28,:) = [x x y y z z]; nxsyszs(28,:) = [2 2 2]; mu(28) =90;

    T = [ ...
        12 0 0 13; ...
        10 2 0 143; ...
        8 4 0 429; ...
        6 6 0 600.6; ...
        8 2 2 1287; ...
        6 4 2 3003; ...
        4 4 4 5005];
    
end

matHRT = zeros(nCoef,nCoef);
for m=1:nCoef
    for k=1:nCoef
        
        sumi = 0;
        for i=1:NLEC
            fack = 1;
            facm = 1;
            for p=1:rank
                fack = fack * orientations(i, CoeffDeff(k,p));
                facm = facm * orientations(i, CoeffDeff(m,p));
            end
            sumi = sumi + fack*facm;
        end
        matHRT(m,k) = b^2*mu(k)*mu(m)*sumi;
    end  
end

%compute the coefficients  given directions, mu, b value etc,
fac_m_i_b_mu = zeros(nCoef,NLEC);
for m=1:nCoef
    for i=1:NLEC
        facm = 1;
        for p=1:rank
            facm = facm * orientations(i, CoeffDeff(m,p));
        end
        fac_m_i_b_mu(m,i) = b*mu(m)*facm;
    end
end
