function ok = saveNifti(filename,volume,intent_code,spacex,spacey,spacez)
%saveNifti      Save nifti volume.
%
%   ok = saveNifti(filename,volume,intent_code,spacex,spacey,spacez) 
%   Save VOLUME using file name FILENAME in NIFTI (.nii) format with intent code
%   INTENT_CODE and voxel size [SPACEX,SPACEY,SPACEZ].
%   
%
%   Alonso Ramirez.  
%   $Date: 2008/10/21$

ok =0;

[ny nx nz nv nw] = size(volume);

% taking example of creating a simulated .nii file.
dat         = file_array;
dat.fname   = filename;

if nw ~= 1
    dat.dim     = [ny nx nz nv nw];
else
    if nv ~= 1
        dat.dim     = [ny nx nz nv];
    else
        dat.dim     = [ny nx nz];
    end
end


dat.dtype   = 'FLOAT32-LE';

[pth,nam,suf]  = fileparts(filename);

if any(strcmp(suf,{'.img','.IMG'}))
    dat.offset  = 0; %hdr + img, no offset
elseif any(strcmp(suf,{'.nii','.NII'}))
    dat.offset  = ceil(348/8)*8; %nii have offset
else
    error(['Unknown filename extension (' suf ').']);
end;

% Create an empty NIFTI structure
N = nifti;

% Creating all the NIFTI header stuff
N.dat = dat;
N.mat = [spacex 0 0 114 ; 0 spacey 0 -70; 0 0 spacez -52; 0 0 0 1];
N.mat_intent = 'Aligned'; % dump possibilities
N.mat0 = N.mat;
N.mat0_intent = 'Aligned';

%     0) NONE    2) CORREL    3) TTEST    4) FTEST    5) ZSCORE    6) CHISQ    7) BETA
%     8) BINOM    9) GAMMA   10) POISSON   11) NORMAL   12) FTEST_NONC   13) CHISQ_NONC
%    14) LOGISTIC   15) LAPLACE   16) UNIFORM   17) TTEST_NONC   18) WEIBULL   19) CHI
%    20) INVGAUSS   21) EXTVAL   22) PVAL   23) LOGPVAL   24) LOG10PVAL 1001) ESTIMATE
%  1002) LABEL 1003) NEURONAMES 1004) MATRIX 1005) MATRIX_SYM 1006) DISPLACEMENT
%  1007) VECTOR 1008) POINTS 1009) TRIANGLE 1010) QUATERNION 1011) DIMLESS

N.intent.code=intent_code ; % dump possibilities
%N.intent.param = [4 8];

N.descrip = 'This is a NIFTI-1 file';

create(N); % Writes hdr info

%% Note that this call writes the data to the disk file
dat(:,:,:,:,:)=volume; % Write out the data as all zeros

ok = 1;
