function [maxV, meanV, minV, stdV] = statsNDVolume(volume,mask)
%statsNDVolume      Compute statistical values of a volume.
%
%   [maxV, meanV, minV, stdV] = statsNDVolume(volume,mask) 
%   Given a VOLUME (maximum 5D) and a MASK, it computes the statistical values only for the
%   values inside MASK. Returns max min mean and std.deviation in parameters
%   MAXV, MEANV, MINV, STDV respectively.
%
%   Alonso Ramirez.  
%   $Date: 2008/10/21$

[ny,nx,nz,nv,nw] = size(volume);

maskD = zeros(size(volume));

if nv>1 | nw>1
    for i=1:nv
        for j=1:nw
            maskD(:,:,:,i,j) = mask; %apply mask to each 3D volume
        end
    end
else
    maskD = mask;
end

vecVals = reshape(volume,ny*nx*nz*nv*nw,1);
maskV = reshape(maskD,ny*nx*nz*nv*nw,1);



vecVals = vecVals(maskV~=0);

meanV = mean(vecVals);

stdV = std(vecVals);

minV = min(vecVals);

maxV = max(vecVals);

